function recPattern = Get_Bits(fsxID, fileName, transmPattern)
%% tt5_ar_1 analyzes a data file and prepares it for the SMBV
% this function analyzes analogue input data read from file <fileName> and
% converts it into binary data.
%
% exemplary use:   transPattern = tt5_ar_1('RadarRecord.dat');

global settings;

%% adapt on input file
% if the input file was recorded using recordData.m, a .csv file was
% automatically created. This file can directly be imported into MATLAB.
% In case the file was recorded by hand, it is stored as a .dat file
% containing ASCI information about the instrument settings. The first and
% last line to be read has to be identified. e.g. line 4 - 19999 contain
% real data, command will be dlmread(fileName, ';', [4, 0, 19999, 2]);
if ~isempty(strfind(fileName, 'dat')) || ~isempty(strfind(fileName, 'DAT'))
    % if file is in .dat format, MATLAB assumes that its located on the FSx
    data = dlmread(['\\' fsxID '\user\' fileName], ';', [40, 0, 19999, 2]);
elseif ~isempty(strfind(fileName, 'csv')) || ~isempty(strfind(fileName, 'CSV'))
    data = csvread(fileName);
end

%% plot incoming data
hFig = figure(1);
clf(hFig);
set(hFig, 'Position', [100 100 700 800]);
subplot(3,2,1);
plot(data(:,1),data(:,2));
title('Recorded data in time domain');
ylabel('Phase [rad]'); xlabel('samples');
grid on;

%% demodulate the bit sequence
% map the recorded data sequence into IQ constellation diagram. Perform
% hard decision to obtain binary data. Convert from -1/+1 to 0/1.

iqData = exp(1i*data(:,2));
demodData = real(iqData);
bitSequence = -(sign(demodData)-1)/2;

subplot(3,2,2);plot(iqData,'.');
title('Recorded data in IQ-domain');
ylabel('Quadratur-part');xlabel('Inphase-part');
axis([-1.2 1.2 -1.2 1.2]);
grid on;

% extract the time for a single bit change by taking the mean of the
% minimum time between bit changes.
[bitChanges, ~] = find(abs(diff(bitSequence))>0);
bitChangeTime = diff(bitChanges);
oneBitChanges = bitChangeTime<1.5*min(bitChangeTime(bitChangeTime>30)) & bitChangeTime > 30;
bitDur = round(mean(bitChangeTime(oneBitChanges)));

% resample the bit sequence by using the sample time extracted before
recPattern = bitSequence(round(bitDur/2):bitDur:length(bitSequence))';

%% plot the transmitted bit Sequence
subplot(3,2,3:4);
stairs(transmPattern, 'LineWidth', 2);
ylim([-0.5, 1.5]); xlim([0, 14]);
title('Transmitted bit pattern');
grid on;

%% plot the received bit sequence
subplot(3,2,5:6)
stairs(recPattern, 'LineWidth', 2);
ylim([-0.5, 1.5]); xlim([0, 14]);
title('Received bit pattern');
grid on;
